@@ -1,21 +1,18 @@
 //! A library to parse epub files
 //!
 //! Design goals:
-//! - parse an epub file into a simple text-only book structure 
-//!   (implemented)
-//! - parse an epub file into a low-level epub structure,
-//!   that exposes all resources in an comprehensive API
-//!   (later versions)
-//!
-//! Atm only epub version 2 is supported, but I'm planning to also support 3.0.1/3.2.
-//! Most of the time newer versions include all the files needed to be 
-//! backwards compatible with version 2 though, so the current implementation often works for version 3 too.
+//! - ✅ serve as core to the epubparse-wasm library (must compile to WASM)
+//! - ✅ perform a reasonable conversion into a book with chapters
+//! - ✅ support Epub version 2 table of contents (.ncx)
+//! - ❌ support Epub version 3 table of contents (.xhtml) (not yet implemented, but
+//!   many version 3 epubs also include version 2 table of contents, these should also work)
 
 use errors::ParseError;
 use parse::EpubArchive;
 use types::Book;
 
 pub mod errors;
+mod html_entities;
 mod parse;
 pub mod types;
 mod util;
